

DALQuery
=======================

.. currentmodule:: pyvo.dal.query

.. autoclass:: DALQuery
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~DALQuery.baseurl
      ~DALQuery.protocol
      ~DALQuery.std_parameters
      ~DALQuery.version

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~DALQuery.execute
      ~DALQuery.execute_raw
      ~DALQuery.execute_stream
      ~DALQuery.execute_votable
      ~DALQuery.getqueryurl
      ~DALQuery.submit

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: baseurl
   .. autoattribute:: protocol
   .. autoattribute:: std_parameters
   .. autoattribute:: version

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: execute
   .. automethod:: execute_raw
   .. automethod:: execute_stream
   .. automethod:: execute_votable
   .. automethod:: getqueryurl
   .. automethod:: submit

   
   